==> ejc-quality-impl-3.0.0-20241121.025753-104-sources.jar: com/ejianc/business/quality/enums/ApplicableScopeEnum.java <==
package com.ejianc.business.quality.enums;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONUtil;
import com.beust.jcommander.internal.Lists;
import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.List;
import java.util.StringJoiner;

/**
 * @Author: LCL
 * @Date: 2024/5/10 下午2:57
 * @Description: 适用范围(公司部门 、 公司直管项目 、 公司所属单位 / 项目)
 */
@Getter
@AllArgsConstructor
public enum ApplicableScopeEnum {
    /**
     * 公司部门
     */
    DEPARTMENT("DEPARTMENT", "公司部门", "0"),
    /**
     * 公司直管项目
     */
    STRAIGHTPIPES("STRAIGHTPIPES", "公司直管项目", "1"),
    /**
     * 公司所属单位/项目
     */
    AFFILIATIONPROJECT("AFFILIATIONPROJECT", "公司所属单位/项目", "2"),
    ;

    private final String scopeCode;

    private final String scopeName;

    private final String apiCode;

    public static final ApplicableScopeEnum[] VALUES;

    static {
        VALUES = values();
    }

    public static String getNameByCode(String scopeCode) {
        JSONArray objects = JSONUtil.parseArray(scopeCode, true);
        StringJoiner stringJoiner = new StringJoiner(",");
        for (Object object : objects) {
            for (ApplicableScopeEnum applicableScopeEnum : values()) {
                if (applicableScopeEnum.getScopeCode().equals(object)) {
                    stringJoiner.add(applicableScopeEnum.getScopeName());
                }
            }
        }
        return stringJoiner.toString();
    }

    /**
     * api数据转换
     */
    public static String conversionApiData(String syfw) {
        String[] split = syfw.split(",");
        List<String> objects = Lists.newArrayList();
        for (String apiCode : split) {
            String scopeCodeByApiCode = getScopeCodeByApiCode(apiCode);
            objects.add(scopeCodeByApiCode);
        }
        return JSONUtil.toJsonStr(objects);
    }

    public static String getScopeCodeByApiCode(String apiCode) {
        for (ApplicableScopeEnum applicableScopeEnum : values()) {
            if (applicableScopeEnum.getApiCode().equals(apiCode)) {
                return applicableScopeEnum.getScopeCode();
            }
        }
        return "errorCode";
    }
}

==> ejc-quality-impl-3.0.0-20250513.021223-129-sources.jar: com/ejianc/business/quality/enums/ApplicableScopeEnum.java <==
package com.ejianc.business.quality.enums;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONUtil;
import com.beust.jcommander.internal.Lists;
import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.List;
import java.util.StringJoiner;

/**
 * @Author: LCL
 * @Date: 2024/5/10 下午2:57
 * @Description: 适用范围(公司部门 、 公司直管项目 、 公司所属单位 / 项目)
 */
@Getter
@AllArgsConstructor
public enum ApplicableScopeEnum {
    /**
     * 公司部门
     */
    DEPARTMENT("DEPARTMENT", "公司部门", "0"),
    /**
     * 公司直管项目
     */
    STRAIGHTPIPES("STRAIGHTPIPES", "公司直管项目", "1"),
    /**
     * 公司所属单位/项目
     */
    AFFILIATIONPROJECT("AFFILIATIONPROJECT", "公司所属单位/项目", "2"),
    ;

    private final String scopeCode;

    private final String scopeName;

    private final String apiCode;

    public static final ApplicableScopeEnum[] VALUES;

    static {
        VALUES = values();
    }

    public static String getNamesByCodes(String scopeCode) {
        JSONArray objects = JSONUtil.parseArray(scopeCode, true);
        StringJoiner stringJoiner = new StringJoiner(",");
        for (Object object : objects) {
            for (ApplicableScopeEnum applicableScopeEnum : values()) {
                if (applicableScopeEnum.getScopeCode().equals(object)) {
                    stringJoiner.add(applicableScopeEnum.getScopeName());
                }
            }
        }
        return stringJoiner.toString();
    }

    /**
     * api数据转换
     */
    public static String conversionApiData(String syfw) {
        String[] split = syfw.split(",");
        List<String> objects = Lists.newArrayList();
        for (String apiCode : split) {
            String scopeCodeByApiCode = getScopeCodeByApiCode(apiCode);
            objects.add(scopeCodeByApiCode);
        }
        return JSONUtil.toJsonStr(objects);
    }

    public static String getScopeCodeByApiCode(String apiCode) {
        for (ApplicableScopeEnum applicableScopeEnum : values()) {
            if (applicableScopeEnum.getApiCode().equals(apiCode)) {
                return applicableScopeEnum.getScopeCode();
            }
        }
        return "errorCode";
    }
}
